# SPDX-License-Identifier: Apache-2.0
# Licensed to the Ed-Fi Alliance under one or more agreements.
# The Ed-Fi Alliance licenses this file to you under the Apache License, Version 2.0.
# See the LICENSE and NOTICES files in the project root for more information.

ASSIGNMENT = "assignment"
ASSIGNMENTS = "assignments"
ATTENDANCE_EVENTS = "attendance-events"
GRADES = "grades"
LMS_SECTION_SOURCE_SYSTEM_IDENTIFIER = "LMSSectionSourceSystemIdentifier"
SECTION = "section"
SECTIONS = "sections"
SECTION_ASSOCIATIONS = "section-associations"
SECTION_ACTIVITIES = "section-activities"
SOURCE_SYSTEM_IDENTIFIER = "SourceSystemIdentifier"
SUBMISSIONS = "submissions"
SYSTEM_ACTIVITIES = "system-activities"
USERS = "users"
